@@ -6,9 +6,10 @@
 2021/4/10 11:00   satan      1.0         None
 """
 from .JCoder_redis import Redis
-from .dict import Dict
-from .set import Set
+from .redis_dict import r_dict
+from .redis_set import r_set
 from .ordered_set import Ordered_set
-from .int import Int
-from .float import Float
-from .list import List
+from .redis_int import r_int
+from .redis_float import r_float
+from .redis_list import r_list
+from .redis_string import r_str
